@@ -331,7 +331,7 @@
             var $library = this.element,
                 uris = this.options.uri ? [this.options.uri] : undefined;
             $.mopidy.connect().then(function() {
-                this.library.search( { any: query }, uris ).then(function( results ) {
+                this.library.search( { any: [ query ] }, uris ).then(function( results ) {
                     $library.empty();
                     $.each( results, function() {
                         var i;
